# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/).

## [Unreleased]

## [2022.4.0]

### Added
- initial release

[Unreleased]: https://gitlab.com/yaq/yaqd-ekspla/-/compare/v2022.4.0...main
[2022.4.0]: https://gitlab.com/yaq/yaqd-ekspla/-/tags/v2022.4.0
